package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.EmsObjModel;

import java.util.List;

/**
 * 能源对象属性Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-23
 */
public interface EmsObjModelMapper {
    /**
     * 查询能源对象属性
     *
     * @param id 能源对象属性主键
     * @return 能源对象属性
     */
    EmsObjModel selectObjModelById(Long id);

    /**
     * 查询能源对象属性
     *
     * @param code 能源对象属性code
     * @return 能源对象属性
     */
    EmsObjModel selectByModelCode(String code);

    /**
     * 查询能源对象属性列表
     *
     * @param emsObjModel 能源对象属性
     * @return 能源对象属性集合
     */
    List<EmsObjModel> selectObjModelList(EmsObjModel emsObjModel);

    /**
     * 新增能源对象属性
     *
     * @param emsObjModel 能源对象属性
     * @return 结果
     */
    int insertObjModel(EmsObjModel emsObjModel);

    /**
     * 修改能源对象属性
     *
     * @param emsObjModel 能源对象属性
     * @return 结果
     */
    int updateObjModel(EmsObjModel emsObjModel);

    /**
     * 删除能源对象属性
     *
     * @param id 能源对象属性主键
     * @return 结果
     */
    int deleteObjModelById(Long id);

    /**
     * 批量删除能源对象属性
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteObjModelByIds(Long[] ids);
}
